==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/ja_utf8/main.php <==
<?php

//          index.php          //
define('_MD_PRINTER','印刷用ページ');
define('_MD_SENDSTORY','このニュースを友達に送る');
define('_MD_READMORE','続きを読む');
define('_MD_COMMENTS','0コメント');
define('_MD_ONECOMMENT','1コメント');
define('_MD_BYTESMORE','残り%s字');
define('_MD_NUMCOMMENTS','%sコメント');

//          submit.php          //
define('_MD_SUBMITNEWS','ニュース投稿');
define('_MD_TITLE','表題');
define('_MD_TOPIC','カテゴリ');
define('_MD_THESCOOP','メッセージ本文');
define('_MD_NOTIFYPUBLISH','ニュースが承認された旨をメールで受け取る');
define('_MD_POST','投稿する');
define('_MD_GO','送信');
define('_MD_THANKS','投稿を受付けました。当サイトスタッフによる承認を経た後に正式掲載となることをご了承ください。'); //submission of news article
define('_MD_THANKS_AUTOAPPROVE', '投稿ありがとうございました。');
define('_MD_THANKS_BUT_ERROR', '投稿ありがとうございました。しかし、<span style="color:red">エラー</span>が発生したため記事が送信されませんでした。お手数ですが管理者にお問い合わせください。');
define('_MD_USE_HTML','HTMLを有効にする');
define('_MD_USE_SMILEY','顔アイコンを有効にする');
define('_MD_USE_BR','改行を自動挿入する');
define('_MD_USE_XCODE','XOOPSコードを有効にする');
define('_MD_NO_TOPICS','カテゴリがありません。');
define('_MD_TOPIC_IMAGE','カテゴリアイコン'); // ver 2.00 added
define('_MD_TOPIC_DISABLE','カテゴリアイコンを表示しない'); // ver 2.00 added
define('_MD_TOPIC_LEFT','カテゴリアイコンを左側に表示する'); // ver 2.00 added
define('_MD_TOPIC_RIGHT','カテゴリアイコンを右側に表示する'); // ver 2.00 added
define('_MD_PUBINHOME','メインページに掲載する'); // ver 2.00 added
define('_MD_PUBLISHED','掲載日時'); // ver 2.00 added
define('_MD_EXPIRED','掲載期限'); // ver 2.00 added
define('_MD_SETDATETIME','掲載日時を設定する'); // ver 2.00 added
define('_MD_SETDATETIME_DESC','*チェックをしないと掲載日時は現在の日時になります。'); // ver 2.00 added
define('_MD_SETEXPDATETIME','掲載期限を設定する'); // ver 2.00 added
define('_MD_SETEXPDATETIME_DESC','*チェックをしないと掲載期限の設定は無効になります。'); // ver 2.00 added
define('_MD_APPROVE','この記事を掲載承認状態にする'); // ver 2.00 added
define('_MD_DATE_FORMAT','%y 年 %m 月 %d 日 %h 時 %i 分 %s 秒'); // ver 2.00 added
define('_MD_DBPUDATED','データベースの更新に成功しました。'); // ver 2.00 added
define('_MD_POSTEDBY','投稿者'); // ver 2.00 added
define('_MD_RELATION','この記事に関連した記事'); // ver 2.00 added
define('_MD_ADD_RELATION','関連記事を追加'); // ver 2.00 added
define('_MD_CHECKED_AS_RELATION','関連記事に追加'); // ver 2.00 added
define('_MD_DISP_BLOCK','ブロックに掲載する'); // ver 2.00 added
define('_MD_RUSUREDEL','このニュース記事および記事に対するコメントを全て削除してもいいですか？'); // ver 2.00 added
define('_MD_EMPTYNODELETE', '削除できません'); // ver 2.00 added

//          archive.php          //
define('_MD_NEWSARCHIVES','ニュースアーカイブ');
define('_MD_ARTICLES','ニュース');
define('_MD_VIEWS','ヒット');
define('_MD_DATE','投稿日時');
define('_MD_ACTIONS','操作');
define('_MD_PRINTERFRIENDLY','印刷用ページ');
define('_MD_THEREAREINTOTAL','計 %s 件のニュース記事があります');
define('_MD_INTARTICLE','%sで見つけた興味深いニュース');// %s is your site name
define('_MD_INTARTFOUND','以下は%sで見つけた非常に興味深いニュース記事です：');// %s is your site name
define('_MD_TOPICC','カテゴリ：');
define('_MD_URL','URL：');
define('_MD_NOSTORY','選択されたニュース記事は存在しません');
define('_MD_YEAR_X','%s年');
define('_MD_NO_ARCIVES','アーカイブはありません。');
define('_MD_JANUARY', '1月');
define('_MD_FEBRUARY', '2月');
define('_MD_MARCH', '3月');
define('_MD_APRIL', '4月');
define('_MD_MAY', '5月');
define('_MD_JUNE', '6月');
define('_MD_JULY', '7月');
define('_MD_AUGUST', '8月');
define('_MD_SEPTEMBER', '9月');
define('_MD_OCTOBER', '10月');
define('_MD_NOVEMBER', '11月');
define('_MD_DECEMBER', '12月');

//          print.php          //
define('_MD_URLFORSTORY','このニュース記事が掲載されているURL：');
define('_MD_THISCOMESFROM','%sにて更に多くのニュース記事をよむことができます');// %s represents your site name

//          header.php          //
define('_MD_RSS', 'RSS'); // ver 1.01 added
define('_MD_ARCHIVES','アーカイブ'); // ver 2.00 added

?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/ja_utf8/main.php <==
<?php

//          index.php          //
define('_MD_PRINTER','印刷用ページ');
define('_MD_SENDSTORY','このニュースを友達に送る');
define('_MD_READMORE','続きを読む');
define('_MD_COMMENTS','0コメント');
define('_MD_ONECOMMENT','1コメント');
define('_MD_BYTESMORE','残り%s字');
define('_MD_NUMCOMMENTS','%sコメント');

//          submit.php          //
define('_MD_SUBMITNEWS','ニュース投稿');
define('_MD_TITLE','表題');
define('_MD_TOPIC','カテゴリ');
define('_MD_THESCOOP','メッセージ本文');
define('_MD_INPUTHELPER','入力支援機能のON/OFF');
define('_MD_FCKXOOPS_ONOFF','FCK EditorのON/OFF（一方のエディタでのテキスト変更は他方に反映されていない点に要注意）');
define('_MD_ERROR_REQUIRED','{0}は必ず入力して下さい');
define('_MD_NOTIFYPUBLISH','ニュースが承認された旨をメールで受け取る');
define('_MD_POST','投稿する');
define('_MD_GO','送信');
define('_MD_THANKS','投稿を受付けました。当サイトスタッフによる承認を経た後に正式掲載となることをご了承ください。'); //submission of news article
define('_MD_THANKS_AUTOAPPROVE', '投稿ありがとうございました。');
define('_MD_THANKS_BUT_ERROR', '投稿ありがとうございました。しかし、<span style="color:red">エラー</span>が発生したため記事が送信されませんでした。お手数ですが管理者にお問い合わせください。');
define('_MD_USE_HTML','HTMLを有効にする');
define('_MD_USE_SMILEY','顔アイコンを有効にする');
define('_MD_USE_BR','改行を自動挿入する');
define('_MD_USE_XCODE','XOOPSコードを有効にする');
define('_MD_NO_TOPICS','カテゴリがありません。');
define('_MD_TOPIC_IMAGE','カテゴリアイコン'); // ver 2.00 added
define('_MD_TOPIC_DISABLE','カテゴリアイコンを表示しない'); // ver 2.00 added
define('_MD_TOPIC_LEFT','カテゴリアイコンを左側に表示する'); // ver 2.00 added
define('_MD_TOPIC_RIGHT','カテゴリアイコンを右側に表示する'); // ver 2.00 added
define('_MD_PUBINHOME','メインページに掲載する'); // ver 2.00 added
define('_MD_PUBLISHED','掲載日時'); // ver 2.00 added
define('_MD_EXPIRED','掲載期限'); // ver 2.00 added
define('_MD_SETDATETIME','掲載日時を設定する'); // ver 2.00 added
define('_MD_SETDATETIME_DESC','*チェックをしないと掲載日時は現在の日時になります。'); // ver 2.00 added
define('_MD_SETEXPDATETIME','掲載期限を設定する'); // ver 2.00 added
define('_MD_SETEXPDATETIME_DESC','*チェックをしないと掲載期限の設定は無効になります。'); // ver 2.00 added
define('_MD_APPROVE','この記事を掲載承認状態にする'); // ver 2.00 added
define('_MD_DATE_FORMAT','%y 年 %m 月 %d 日 %h 時 %i 分 %s 秒'); // ver 2.00 added
define('_MD_DBPUDATED','データベースの更新に成功しました。'); // ver 2.00 added
define('_MD_POSTEDBY','投稿者'); // ver 2.00 added
define('_MD_RELATION','この記事に関連した記事'); // ver 2.00 added
define('_MD_ADD_RELATION','関連記事を追加'); // ver 2.00 added
define('_MD_CHECKED_AS_RELATION','関連記事に追加'); // ver 2.00 added
define('_MD_DISP_BLOCK','ブロックに掲載する'); // ver 2.00 added
define('_MD_RUSUREDEL','このニュース記事および記事に対するコメントを全て削除してもいいですか？'); // ver 2.00 added
define('_MD_EMPTYNODELETE', '削除できません'); // ver 2.00 added

//          archive.php          //
define('_MD_NEWSARCHIVES','ニュースアーカイブ');
define('_MD_ARTICLES','ニュース');
define('_MD_VIEWS','ヒット');
define('_MD_DATE','投稿日時');
define('_MD_ACTIONS','操作');
define('_MD_PRINTERFRIENDLY','印刷用ページ');
define('_MD_THEREAREINTOTAL','計 %s 件のニュース記事があります');
define('_MD_INTARTICLE','%sで見つけた興味深いニュース');// %s is your site name
define('_MD_INTARTFOUND','以下は%sで見つけた非常に興味深いニュース記事です：');// %s is your site name
define('_MD_TOPICC','カテゴリ：');
define('_MD_URL','URL：');
define('_MD_NOSTORY','選択されたニュース記事は存在しません');
define('_MD_YEAR_X','%s年');
define('_MD_NO_ARCIVES','アーカイブはありません。');
define('_MD_JANUARY', '1月');
define('_MD_FEBRUARY', '2月');
define('_MD_MARCH', '3月');
define('_MD_APRIL', '4月');
define('_MD_MAY', '5月');
define('_MD_JUNE', '6月');
define('_MD_JULY', '7月');
define('_MD_AUGUST', '8月');
define('_MD_SEPTEMBER', '9月');
define('_MD_OCTOBER', '10月');
define('_MD_NOVEMBER', '11月');
define('_MD_DECEMBER', '12月');

//          print.php          //
define('_MD_URLFORSTORY','このニュース記事が掲載されているURL：');
define('_MD_THISCOMESFROM','%sにて更に多くのニュース記事をよむことができます');// %s represents your site name

//          header.php          //
define('_MD_RSS', 'RSS'); // ver 1.01 added
define('_MD_ARCHIVES','アーカイブ'); // ver 2.00 added

?>
